@@ -164,8 +164,8 @@ def E(expr,color ="red"):
     izquierda = expr.args[0]
     derecha = expr.args[1]
     texto = latemix(izquierda) + " = " + latemix(derecha)
-    return IPython.display.Latex(texto)
+    return IPython.display.display(IPython.display.Latex(texto))
   elif isinstance(expr,list):#Si tenemos un componente
     texto = sympy.latex(expr[0]) + " = " + latemix(expr[1])
-    return IPython.display.Latex(texto)
+    return IPython.display.display(IPython.display.Latex(texto))
 
